@@ -33,12 +33,13 @@ from plainbox import __version__ as plainbox_version
 from plainbox.i18n import gettext as _
 from plainbox.impl.applogic import PlainBoxConfig
 from plainbox.impl.commands import PlainBoxToolBase
-from plainbox.impl.commands.check_config import CheckConfigCommand
+from plainbox.impl.commands.cmd_check_config import CheckConfigCommand
 from plainbox.impl.commands.dev import DevCommand
-from plainbox.impl.commands.run import RunCommand
-from plainbox.impl.commands.selftest import PlainboxSelfTestCommand
-from plainbox.impl.commands.session import SessionCommand
-from plainbox.impl.commands.startprovider import StartProviderCommand
+from plainbox.impl.commands.cmd_device import DeviceCommand
+from plainbox.impl.commands.cmd_run import RunCommand
+from plainbox.impl.commands.cmd_selftest import PlainboxSelfTestCommand
+from plainbox.impl.commands.cmd_session import SessionCommand
+from plainbox.impl.commands.cmd_startprovider import StartProviderCommand
 from plainbox.impl.logging import setup_logging
 
 
@@ -66,9 +67,11 @@ class PlainBoxTool(PlainBoxToolBase):
 
     def create_parser_object(self):
         parser = super().create_parser_object()
-        parser.prog = "plainbox"
-        parser.usage = _("plainbox [--help] [--version] | [options] <command>"
-                         " ...")
+        parser.prog = self.get_exec_name()
+        # TRANSLATORS: '--help' and '--version' are not translatable,
+        # but '[options]' and '<command>' are.
+        parser.usage = _("{0} [--help] [--version] | [options] <command>"
+                         " ...").format(self.get_exec_name())
         return parser
 
     def add_subcommands(self, subparsers):
@@ -79,12 +82,13 @@ class PlainBoxTool(PlainBoxToolBase):
         top-level subcommands.
         """
         # TODO: switch to plainbox plugins
-        RunCommand(self._provider_list, self._config).register_parser(
+        RunCommand(self._load_providers, self._config).register_parser(
             subparsers)
-        SessionCommand(self._provider_list).register_parser(subparsers)
+        SessionCommand(self._load_providers).register_parser(subparsers)
+        DeviceCommand().register_parser(subparsers)
         PlainboxSelfTestCommand().register_parser(subparsers)
         CheckConfigCommand(self._config).register_parser(subparsers)
-        DevCommand(self._provider_list, self._config).register_parser(
+        DevCommand(self._load_providers, self._config).register_parser(
             subparsers)
         StartProviderCommand().register_parser(subparsers)
 
@@ -105,10 +109,32 @@ class PlainBoxTool(PlainBoxToolBase):
         return os.getenv("PLAINBOX_LOCALE_DIR", None)
 
 
+class StubBoxTool(PlainBoxTool):
+    """
+    Command line interface to StubBox
+
+    The 'stubbox' executable is just just like plainbox but it contains the
+    special stubbox provider with representative test jobs.
+    """
+
+    @classmethod
+    def get_exec_name(cls):
+        return "stubbox"
+
+    def _load_providers(self):
+        logger.info("Loading stubbox provider...")
+        from plainbox.impl.providers.special import get_stubbox
+        return [get_stubbox()]
+
+
 def main(argv=None):
     raise SystemExit(PlainBoxTool().main(argv))
 
 
+def stubbox_main(argv=None):
+    raise SystemExit(StubBoxTool().main(argv))
+
+
 def get_parser_for_sphinx():
     return PlainBoxTool().construct_parser()
 
