@@ -1,13 +1,12 @@
 # This file is part of Checkbox.
 #
-# Copyright 2013 Canonical Ltd.
+# Copyright 2012-2014 Canonical Ltd.
 # Written by:
 #   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
 #
 # Checkbox is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 3,
 # as published by the Free Software Foundation.
-
 #
 # Checkbox is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,7 +15,6 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
-
 """
 :mod:`plainbox.impl.commands.dev` -- dev sub-command
 ====================================================
@@ -30,13 +28,13 @@ from logging import getLogger
 
 from plainbox.i18n import gettext as _
 from plainbox.impl.commands import PlainBoxCommand
-from plainbox.impl.commands.analyze import AnalyzeCommand
+from plainbox.impl.commands.cmd_analyze import AnalyzeCommand
 from plainbox.impl.commands.crash import CrashCommand
-from plainbox.impl.commands.list import ListCommand
+from plainbox.impl.commands.cmd_list import ListCommand
 from plainbox.impl.commands.logtest import LogTestCommand
-from plainbox.impl.commands.parse import ParseCommand
-from plainbox.impl.commands.script import ScriptCommand
-from plainbox.impl.commands.special import SpecialCommand
+from plainbox.impl.commands.cmd_parse import ParseCommand
+from plainbox.impl.commands.cmd_script import ScriptCommand
+from plainbox.impl.commands.cmd_special import SpecialCommand
 
 
 logger = getLogger("plainbox.commands.dev")
@@ -47,8 +45,8 @@ class DevCommand(PlainBoxCommand):
     Command hub for various development commands.
     """
 
-    def __init__(self, provider_list, config):
-        self.provider_list = provider_list
+    def __init__(self, provider_loader, config):
+        self.provider_loader = provider_loader
         self.config = config
 
     def invoked(self, ns):
@@ -56,12 +54,14 @@ class DevCommand(PlainBoxCommand):
 
     def register_parser(self, subparsers):
         parser = subparsers.add_parser(
-            "dev", help=_("development commands"))
+            "dev", help=_("development commands"),
+            prog="plainbox dev",
+            usage=_("plainbox dev <subcommand> ..."))
         subdev = parser.add_subparsers()
-        ScriptCommand(self.provider_list, self.config).register_parser(subdev)
-        SpecialCommand(self.provider_list, self.config).register_parser(subdev)
-        AnalyzeCommand(self.provider_list, self.config).register_parser(subdev)
+        ScriptCommand(self.provider_loader, self.config).register_parser(subdev)
+        SpecialCommand(self.provider_loader, self.config).register_parser(subdev)
+        AnalyzeCommand(self.provider_loader, self.config).register_parser(subdev)
         ParseCommand().register_parser(subdev)
         CrashCommand().register_parser(subdev)
         LogTestCommand().register_parser(subdev)
-        ListCommand(self.provider_list).register_parser(subdev)
+        ListCommand(self.provider_loader).register_parser(subdev)
