@@ -1,13 +1,12 @@
 # This file is part of Checkbox.
 #
-# Copyright 2013 Canonical Ltd.
+# Copyright 2012-2014 Canonical Ltd.
 # Written by:
 #   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
 #
 # Checkbox is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 3,
 # as published by the Free Software Foundation.
-
 #
 # Checkbox is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,14 +15,12 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
-
 """
 plainbox.impl.commands.test_dev
 ===============================
 
 Test definitions for plainbox.impl.dev module
 """
-
 import argparse
 from inspect import cleandoc
 from unittest import TestCase
@@ -38,17 +35,17 @@ class TestDevCommand(TestCase):
     def setUp(self):
         self.parser = argparse.ArgumentParser(prog='test')
         self.subparsers = self.parser.add_subparsers()
-        self.provider_list = [mock.Mock()]
+        self.provider_loader = lambda: [mock.Mock()]
         self.config = mock.Mock()
         self.ns = mock.Mock()
 
     def test_init(self):
-        dev_cmd = DevCommand(self.provider_list, self.config)
-        self.assertIs(dev_cmd.provider_list, self.provider_list)
+        dev_cmd = DevCommand(self.provider_loader, self.config)
+        self.assertIs(dev_cmd.provider_loader, self.provider_loader)
         self.assertIs(dev_cmd.config, self.config)
 
     def test_register_parser(self):
-        DevCommand(self.provider_list, self.config).register_parser(
+        DevCommand(self.provider_loader, self.config).register_parser(
             self.subparsers)
         with TestIO() as io:
             self.parser.print_help()
@@ -60,7 +57,7 @@ class TestDevCommand(TestCase):
         self.assertEqual(
             io.stdout, cleandoc(
                 """
-                usage: test dev [-h] {script,special,analyze,parse,crash,logtest,list} ...
+                usage: plainbox dev <subcommand> ...
 
                 positional arguments:
                   {script,special,analyze,parse,crash,logtest,list}
